@@ -5,6 +5,8 @@ import logging
 STX = chr(0x02)
 ETX = chr(0x03)
 
+_LOGGER = logging.getLogger(__name__)
+
 class ResponseType(Enum):
     ERROR = 0
     SUCCESS = 1
@@ -26,10 +28,10 @@ class KuroCommand():
             return (STX + '**'+ self.cmd + self.params + ETX).encode('utf8')
     
     def process_response(self, response_str):
-        logging.debug("kurocommand response: " + response_str)
+        _LOGGER.info("kurocommand response: " + response_str)
         if "ERR" in response_str:
             self.response_type = ResponseType.ERROR
-        elif "XXX" in response_str:
+        elif self.cmd in response_str:
             self.response_type = ResponseType.SUCCESS
         else:
             self.response_type = ResponseType.NOT_PROCESSED
@@ -57,7 +59,7 @@ class ParameterCommand(KuroCommand):
             self.response = response_str[idx:idx + 3]
         else:
             self.response = None
-        logging.debug("response" + str(self.response))
+        _LOGGER.info("response" + str(self.response))
 
 
 class OsdState(Enum):
@@ -308,10 +310,10 @@ class PictureOffCommand(ParameterCommand):
     def __init__(self, picture_off_status = PictureOffStatus.NONE):
         super().__init__("VMT", picture_off_status.value)
 
-    # def process_response(self, response):
-    #     super().process_response(response)
-    #     if (self.response_type == ResponseType.SUCCESS 
-    #     and self.params == None )  or self.response_type == ResponseType.ERROR:
-    #         self.is_muted = PictureOffStatus.NONE
-    #     else:
-    #         self.is_muted = PictureOffStatus(self.response[1:])
+    def process_response(self, response):
+        super().process_response(response)
+        if (self.response_type == ResponseType.SUCCESS 
+        and self.params == None )  or self.response_type == ResponseType.ERROR:
+            self.is_muted = PictureOffStatus.NONE
+        else:
+            self.is_muted = PictureOffStatus(self.response[1:])
